rename objects to deck / slide
[smdp.git] / tmp.c
diff --git a/tmp.c b/tmp.c
index 7e8589e..fef4fef 100644 (file)
--- a/tmp.c
+++ b/tmp.c
@@ -58,10 +58,12 @@ int main(int argc, char *argv[]) {
         input = stdin;
     }
 
-    // load document object from input
-    document_t *doc;
+    // load deck object from input
+    deck_t *doc;
     doc = markdown_load(input);
 
+    //TODO close file
+
     if(debug > 0) {
         markdown_debug(doc, debug);
     }